@@ -33,6 +33,7 @@ class Task(Logger):
         self.set_log_name()
         self._task_input = kwargs
         self._validate_input_params()
+        self._populate_empty_param()
         self.execute()
         return self.get_output()
 
@@ -42,6 +43,11 @@ class Task(Logger):
                 self.error("Unexpected Task input parameter: {}".format(key))
                 raise ValueError
 
+    def _populate_empty_param(self):
+        for key in self._task_params.keys():
+            if key not in self._task_input.keys():
+                self._task_input[key] = self._task_params[key]['default']
+
     def get_output(self):
         return self._output
 
@@ -51,7 +57,8 @@ class Task(Logger):
     def get_task_param(self, paramName):
         return self._task_input[paramName]
 
-    def addTaskParam(self, param_name, param_description):
+    def addTaskParam(self, param_name, param_description, default=None):
         if self._task_params is None:
             self._task_params = {}
-        self._task_params[param_name] = {"description": param_description}
+        self._task_params[param_name] = {"description": param_description,
+                                         "default": default}
